@@ -1,5 +1,7 @@
+import glob
 import os
 from importlib.util import module_from_spec, spec_from_file_location
+from pathlib import Path
 from types import ModuleType
 from typing import Any, Dict
 
@@ -21,71 +23,53 @@ def _load_py_module(name: str, location: str) -> ModuleType:
     return py
 
 
+def _load_assistant() -> ModuleType:
+    location = os.path.join(_PROJECT_ROOT, ".actions", "assistant.py")
+    return _load_py_module("assistant", location)
+
+
 def _prepare_extras() -> Dict[str, Any]:
-    path_setup_tools = os.path.join(_PROJECT_ROOT, ".actions", "setup_tools.py")
-    setup_tools = _load_py_module("setup_tools", path_setup_tools)
+    assistant = _load_assistant()
     # https://setuptools.readthedocs.io/en/latest/setuptools.html#declaring-extras
     # Define package extras. These are only installed if you specify them.
     # From remote, use like `pip install pytorch-lightning[dev, docs]`
     # From local copy of repo, use like `pip install ".[dev, docs]"`
-    common_args = dict(path_dir=_PATH_REQUIREMENTS, unfreeze="major" if _FREEZE_REQUIREMENTS else "all")
+    req_files = [Path(p) for p in glob.glob(os.path.join(_PATH_REQUIREMENTS, "*.txt"))]
+    common_args = dict(path_dir=_PATH_REQUIREMENTS, unfreeze="none" if _FREEZE_REQUIREMENTS else "major")
     extras = {
-        # 'docs': load_requirements(file_name='docs.txt'),
-        "cloud": setup_tools.load_requirements(file_name="cloud.txt", **common_args),
-        "ui": setup_tools.load_requirements(file_name="ui.txt", **common_args),
-        "test": setup_tools.load_requirements(file_name="test.txt", **common_args),
+        p.stem: assistant.load_requirements(file_name=p.name, **common_args)
+        for p in req_files
+        if p.name not in ("docs.txt", "devel.txt", "base.txt")
     }
-    extras["extra"] = extras["cloud"] + extras["ui"]
-    extras["dev"] = extras["extra"] + extras["test"]  # + extras['docs']
-    extras["all"] = extras["dev"]
+    extras["extra"] = extras["cloud"] + extras["ui"] + extras["components"]
+    extras["all"] = extras["extra"]
+    extras["dev"] = extras["all"] + extras["test"]  # + extras['docs']
     return extras
 
 
-def _adjust_manifest(**__: Any) -> None:
-    manifest_path = os.path.join(_PROJECT_ROOT, "MANIFEST.in")
-    assert os.path.isfile(manifest_path)
-    with open(manifest_path) as fp:
-        lines = fp.readlines()
-    lines += [
-        "recursive-exclude src *.md" + os.linesep,
-        "recursive-exclude requirements *.txt" + os.linesep,
-        "recursive-include src/lightning_app *.md" + os.linesep,
-        "include src/lightning_app/components/serve/catimage.png" + os.linesep,
-        "recursive-include requirements/app *.txt" + os.linesep,
-        "recursive-include src/lightning_app/cli/*-template *" + os.linesep,  # Add templates
-    ]
-
-    # TODO: remove this once lightning-ui package is ready as a dependency
-    lines += ["recursive-include src/lightning_app/ui *" + os.linesep]
-
-    with open(manifest_path, "w") as fp:
-        fp.writelines(lines)
-
-
-def _setup_args(**__: Any) -> Dict[str, Any]:
-    _path_setup_tools = os.path.join(_PROJECT_ROOT, ".actions", "setup_tools.py")
-    _setup_tools = _load_py_module("setup_tools", _path_setup_tools)
-    _about = _load_py_module("about", os.path.join(_PACKAGE_ROOT, "__about__.py"))
-    _version = _load_py_module("version", os.path.join(_PACKAGE_ROOT, "__version__.py"))
-    _long_description = _setup_tools.load_readme_description(
-        _PACKAGE_ROOT, homepage=_about.__homepage__, version=_version.version
+def _setup_args() -> Dict[str, Any]:
+    assistant = _load_assistant()
+    about = _load_py_module("about", os.path.join(_PACKAGE_ROOT, "__about__.py"))
+    version = _load_py_module("version", os.path.join(_PACKAGE_ROOT, "__version__.py"))
+    long_description = assistant.load_readme_description(
+        _PACKAGE_ROOT, homepage=about.__homepage__, version=version.version
     )
 
     # TODO: remove this once lightning-ui package is ready as a dependency
-    _setup_tools._download_frontend(_PACKAGE_ROOT)
+    assistant._download_frontend(_PACKAGE_ROOT)
 
     return dict(
         name="lightning-app",
-        version=_version.version,  # todo: consider using date version + branch for installation from source
-        description=_about.__docs__,
-        author=_about.__author__,
-        author_email=_about.__author_email__,
-        url=_about.__homepage__,
+        version=version.version,
+        description=about.__docs__,
+        author=about.__author__,
+        author_email=about.__author_email__,
+        url=about.__homepage__,
         download_url="https://github.com/Lightning-AI/lightning",
-        license=_about.__license__,
+        license=about.__license__,
         packages=find_packages(where="src", include=["lightning_app", "lightning_app.*"]),
         package_dir={"": "src"},
-        long_description=_long_description,
+        long_description=long_description,
         long_description_content_type="text/markdown",
         include_package_data=True,
         zip_safe=False,
@@ -96,9 +80,9 @@ def _setup_args(**__: Any) -> Dict[str, Any]:
                 "lightning = lightning_app.cli.lightning_cli:main",
             ],
         },
-        setup_requires=["wheel"],
-        install_requires=_setup_tools.load_requirements(
-            _PATH_REQUIREMENTS, unfreeze="major" if _FREEZE_REQUIREMENTS else "all"
+        setup_requires=[],
+        install_requires=assistant.load_requirements(
+            _PATH_REQUIREMENTS, unfreeze="none" if _FREEZE_REQUIREMENTS else "major"
         ),
         extras_require=_prepare_extras(),
         project_urls={
