@@ -1,3 +1,17 @@
+# Copyright The Lightning AI team.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 import os
 import shutil
 import sys
@@ -19,17 +33,25 @@ from lightning_app.cli import cmd_init, cmd_install, cmd_pl_init, cmd_react_ui_i
 from lightning_app.cli.cmd_apps import _AppManager
 from lightning_app.cli.cmd_clusters import AWSClusterManager
 from lightning_app.cli.commands.app_commands import _run_app_command
-from lightning_app.cli.commands.connection import (
+from lightning_app.cli.commands.cd import cd
+from lightning_app.cli.commands.cp import cp
+from lightning_app.cli.commands.logs import logs
+from lightning_app.cli.commands.ls import ls
+from lightning_app.cli.commands.pwd import pwd
+from lightning_app.cli.commands.rm import rm
+from lightning_app.cli.connect.app import (
     _list_app_commands,
     _retrieve_connection_to_an_app,
-    connect,
-    disconnect,
+    connect_app,
+    disconnect_app,
 )
-from lightning_app.cli.commands.logs import logs
+from lightning_app.cli.connect.data import connect_data
+from lightning_app.cli.connect.node import connect_node, disconnect_node
 from lightning_app.cli.lightning_cli_create import create
 from lightning_app.cli.lightning_cli_delete import delete
 from lightning_app.cli.lightning_cli_list import get_list
 from lightning_app.core.constants import DEBUG, ENABLE_APP_COMMENT_COMMAND_EXECUTION, get_lightning_cloud_url
+from lightning_app.runners.cloud import CloudRuntime
 from lightning_app.runners.runtime import dispatch
 from lightning_app.runners.runtime_type import RuntimeType
 from lightning_app.utilities.app_commands import run_app_commands
@@ -102,8 +124,28 @@ def show() -> None:
     pass
 
 
-_main.command()(connect)
-_main.command()(disconnect)
+@_main.group()
+def connect() -> None:
+    """Connect apps and data."""
+    pass
+
+
+@_main.group()
+def disconnect() -> None:
+    """Disconnect apps."""
+    pass
+
+
+connect.command("app")(connect_app)
+disconnect.command("app")(disconnect_app)
+connect.command("node", hidden=True)(connect_node)
+disconnect.command("node", hidden=True)(disconnect_node)
+connect.command("data", hidden=True)(connect_data)
+_main.command(hidden=True)(ls)
+_main.command(hidden=True)(cd)
+_main.command(hidden=True)(cp)
+_main.command(hidden=True)(pwd)
+_main.command(hidden=True)(rm)
 show.command()(logs)
 
 
@@ -158,7 +200,7 @@ def cluster_logs(cluster_id: str, to_time: arrow.Arrow, from_time: arrow.Arrow,
             $ lightning show cluster logs my-cluster --limit 10
     """
 
-    client = LightningClient()
+    client = LightningClient(retry=False)
     cluster_manager = AWSClusterManager()
     existing_cluster_list = cluster_manager.get_clusters()
 
@@ -217,7 +259,7 @@ def login() -> None:
 def logout() -> None:
     """Log out of your lightning.ai account."""
     Auth().clear()
-    disconnect(logout=True)
+    disconnect_app(logout=True)
 
 
 def _run_app(
@@ -374,12 +416,33 @@ def run_app(
     )
 
 
-if RequirementCache("lightning-fabric>=1.9.0.dev0") or RequirementCache("lightning>=1.9.0.dev0"):
-    # lightning.fabric.cli may not be available when installing only standalone lightning-app package
+if RequirementCache("lightning-fabric>=1.9.0") or RequirementCache("lightning>=1.9.0"):
+    # note it is automatically replaced to `from lightning.fabric.cli` when building monolithic/mirror package
     from lightning_fabric.cli import _run_model
 
     run.add_command(_run_model)
 
+
+@_main.command("open", hidden=True)
+@click.argument("path", type=str, default=".")
+@click.option(
+    "--cluster-id",
+    type=str,
+    default=None,
+    help="Open on a specific Lightning AI BYOC compute cluster",
+)
+@click.option("--name", help="The name to use for the CloudSpace", default="", type=str)
+def open(path: str, cluster_id: str, name: str) -> None:
+    """Open files or folders from your machine in a Lightning CloudSpace."""
+
+    if not os.path.exists(path):
+        click.echo(f"The provided path `{path}` doesn't exist.")
+        sys.exit(1)
+
+    runtime = CloudRuntime(entrypoint=Path(path))
+    runtime.open(name, cluster_id)
+
+
 _main.add_command(get_list)
 _main.add_command(delete)
 _main.add_command(create)
