@@ -1,9 +1,10 @@
 from enum import Enum
 
+from lightning_app.core.constants import APP_SERVER_IN_CLOUD
 from lightning_app.runners.backends.backend import Backend
 from lightning_app.runners.backends.cloud import CloudBackend
 from lightning_app.runners.backends.docker import DockerBackend
-from lightning_app.runners.backends.mp_process import MultiProcessingBackend
+from lightning_app.runners.backends.mp_process import CloudMultiProcessingBackend, MultiProcessingBackend
 
 
 class BackendType(Enum):
@@ -13,6 +14,8 @@ class BackendType(Enum):
 
     def get_backend(self, entrypoint_file: str) -> "Backend":
         if self == BackendType.MULTIPROCESSING:
+            if APP_SERVER_IN_CLOUD:
+                return CloudMultiProcessingBackend(entrypoint_file)
             return MultiProcessingBackend(entrypoint_file)
         elif self == BackendType.DOCKER:
             return DockerBackend(entrypoint_file)
