@@ -1,3 +1,17 @@
+# Copyright The Lightning AI team.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 import time
 
 import requests
@@ -26,29 +40,29 @@ class FileUploader:
     workers: int = 8
     retries: int = 10000
     disconnect_retry_wait_seconds: int = 5
-
     progress = Progress(
         TextColumn("[bold blue]{task.description}", justify="left"),
         BarColumn(bar_width=None),
         "[self.progress.percentage]{task.percentage:>3.1f}%",
     )
 
-    def __init__(self, presigned_url: str, source_file: str, total_size: int, name: str):
+    def __init__(self, presigned_url: str, source_file: str, total_size: int, name: str, use_progress: bool = True):
         self.presigned_url = presigned_url
         self.source_file = source_file
         self.total_size = total_size
         self.name = name
+        self.use_progress = use_progress
+        self.task_id = None
 
-    @staticmethod
-    def upload_s3_data(url: str, data: bytes, retries: int, disconnect_retry_wait_seconds: int) -> str:
-        """Send data to s3 url.
+    def upload_data(self, url: str, data: bytes, retries: int, disconnect_retry_wait_seconds: int) -> str:
+        """Send data to url.
 
         Parameters
         ----------
         url: str
-            S3 url string to send data to
+            url string to send data to
         data: bytes
-             Bytes of data to send to S3
+             Bytes of data to send to url
         retries: int
             Amount of retries
         disconnect_retry_wait_seconds: int
@@ -65,24 +79,31 @@ class FileUploader:
                 retries = Retry(total=10)
                 with requests.Session() as s:
                     s.mount("https://", HTTPAdapter(max_retries=retries))
-                    response = s.put(url, data=data)
-                    if "ETag" not in response.headers:
-                        raise ValueError(f"Unexpected response from S3, response: {response.content}")
-                    return response.headers["ETag"]
+                    return self._upload_data(s, url, data)
             except BrokenPipeError:
                 time.sleep(disconnect_retry_wait_seconds)
                 disconnect_retries -= 1
 
         raise ValueError("Unable to upload file after multiple attempts")
 
+    def _upload_data(self, s: requests.Session, url: str, data: bytes):
+        resp = s.put(url, data=data)
+        if "ETag" not in resp.headers:
+            raise ValueError(f"Unexpected response from {url}, response: {resp.content}")
+        return resp.headers["ETag"]
+
     def upload(self) -> None:
         """Upload files from source dir into target path in S3."""
-        task_id = self.progress.add_task("upload", filename=self.name, total=self.total_size)
-        self.progress.start()
+        no_task = self.task_id is None
+        if self.use_progress and no_task:
+            self.task_id = self.progress.add_task("upload", filename=self.name, total=self.total_size)
+            self.progress.start()
         try:
             with open(self.source_file, "rb") as f:
                 data = f.read()
-            self.upload_s3_data(self.presigned_url, data, self.retries, self.disconnect_retry_wait_seconds)
-            self.progress.update(task_id, advance=len(data))
+            self.upload_data(self.presigned_url, data, self.retries, self.disconnect_retry_wait_seconds)
+            if self.use_progress:
+                self.progress.update(self.task_id, advance=len(data))
         finally:
-            self.progress.stop()
+            if self.use_progress and no_task:
+                self.progress.stop()
