@@ -1,3 +1,17 @@
+# Copyright The Lightning AI team.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 import abc
 import asyncio
 import builtins
@@ -588,9 +602,7 @@ def _handle_is_headless(app: "LightningApp"):
             break
 
     if not current_lightningapp_instance:
-        raise RuntimeError(
-            "App was not found. Please open an issue at https://github.com/lightning-AI/lightning/issues."
-        )
+        return
 
     if any(
         [
